@@ -40,6 +40,7 @@ class TitleEntry(inline.InlineElement):
         self.title = match.group(1)
         self.description = match.group(2)
         self.created = match.group(3)
+        self.modified = match.group(4)
         self.tags = match.group(5)
 
 class TitleEntryRendererMixin(object):
@@ -70,12 +71,39 @@ class KrystalExt:
 
 class BlogEntry:
 
-    def __init__(self, timestamp, title, url):
-        self.timestamp = timestamp
+    def __init__(self, id, created_timestamp, modified_timestamp, title, description, url):
+        self.id = id
+        self.timestamp = created_timestamp
+        self.modified_timestamp = modified_timestamp
         self.title = title
+        self.description = description
         self.url = url
 
+def list_entries():
+    posts = os.listdir(post_dir)
+    posts = filter(lambda x: x.endswith('.md'), posts)
+    posts = map(lambda x: x[:-3], posts)
+    posts = list(posts)
 
+    #entries = [BlogEntry(now, x, my_url_for('serve_post', post_id=x)) for x in posts]
+    entries = []
+    for post in posts:
+        marko = Markdown(extensions=[KrystalExt, NewExt, 'codehilite'])
+        parsed = marko.parse(open(f'{post_dir}/{post}.md').read())
+
+        first = parsed.children[0].children[0]
+        if not isinstance(first, TitleEntry):
+            raise ValueError('First element should be title entry')
+
+        year, month, day = tuple(map(lambda x: int(x), first.created.split('-')))
+        created = datetime(year=year, month=month, day=day)
+        year, month, day = tuple(map(lambda x: int(x), first.modified.split('-')))
+        modified = datetime(year=year, month=month, day=day)
+        entries.append(BlogEntry(post, created, modified, first.title, first.description, my_url_for('serve_post', post_id=post)))
+
+
+    entries.sort(key=lambda x: (x.timestamp, x.title), reverse=True)
+    return entries
 
 @app.route('/about/')
 def about():
@@ -94,41 +122,35 @@ def serve_post(post_id):
     post = marko.render(parsed)
     return render_template('post.html', now=now, post=post, post_title=parsed_title, post_description=parsed_desc)
 
+@app.route('/feed.xml')
+def serve_feed():
+    return render_template('feed.xml', entries=list_entries(), now=now), {
+        'Content-Type': 'application/atom+xml; charset=UTF-8',
+    }
+
 @app.route('/')
 def serve_main():
-
-    posts = os.listdir(post_dir)
-    posts = filter(lambda x: x.endswith('.md'), posts)
-    posts = map(lambda x: x[:-3], posts)
-    posts = list(posts)
-
-    #entries = [BlogEntry(now, x, my_url_for('serve_post', post_id=x)) for x in posts]
-    entries = []
-    for post in posts:
-        marko = Markdown(extensions=[KrystalExt, NewExt, 'codehilite'])
-        parsed = marko.parse(open(f'{post_dir}/{post}.md').read())
-
-        first = parsed.children[0].children[0]
-        if not isinstance(first, TitleEntry):
-            raise ValueError('First element should be title entry')
-
-        year, month, day = tuple(map(lambda x: int(x), first.created.split('-')))
-        dt = datetime(year=year, month=month, day=day)
-        entries.append(BlogEntry(dt, first.title, my_url_for('serve_post', post_id=post)))
-
-
-    entries.sort(key=lambda x: (x.timestamp, x.title), reverse=True)
-    return render_template('index.html', entries=entries, now=now)
+    return render_template('index.html', entries=list_entries(), now=now)
 
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument('--port', type=int, default=8080, required=False)
     parser.add_argument('--build', default=False, required=False, action='store_true')
+    parser.add_argument('--base-url', type=str, default=None, required=False)
 
     res = parser.parse_args()
     app.config['TEMPLATES_AUTO_RELOAD'] = True
     app.config['FREEZER_RELATIVE_URLS'] = True
     app.config['FREEZER_DESTINATION'] = f'{CWD}/build'
+    if res.base_url:
+        from urllib.parse import urlparse
+        base_url = urlparse(res.base_url)
+        if base_url.scheme:
+            app.config['PREFERRED_URL_SCHEME'] = base_url.scheme
+        if base_url.netloc:
+            app.config['SERVER_NAME'] = base_url.netloc
+        if base_url.path:
+            app.config['APPLICATION_ROOT'] = base_url.path
 
     if res.build:
         global my_url_for
@@ -137,5 +159,5 @@ def main():
     else:
         app.run('0.0.0.0', res.port, debug=True)
 
-if __name__ == '__name__':
+if __name__ == '__main__':
     exit(main())
